@@ -6,6 +6,8 @@
 """
 Main file containing the mito widget.
 """
+from mitosheet.user.schemas import UJ_FEEDBACKS, UJ_MITOSHEET_LAST_FIFTY_USAGES
+from mitosheet.user.db import get_user_field
 from mitosheet.utils import get_new_id
 from mitosheet.api import API
 from mitosheet.mito_analytics import log, log_event_processed, log_recent_error
@@ -16,16 +18,16 @@ import traitlets as t
 
 from mitosheet._frontend import module_name, module_version
 from mitosheet.errors import EditError, get_recent_traceback_as_list
-from mitosheet.save_utils import (
+from mitosheet.saved_analyses import (
     read_and_upgrade_analysis, 
     write_analysis,
     saved_analysis_names_json
 )
 
-from mitosheet.widget_state_container import WidgetStateContainer
+from mitosheet.steps_manager import StepsManager
 
-from mitosheet.user import is_local_deployment, should_upgrade_mitosheet, should_display_feedback, get_user_field
-from mitosheet.data_in_mito import DataTypeInMito, get_data_type_in_mito
+from mitosheet.user import is_local_deployment, should_upgrade_mitosheet
+from mitosheet.data_in_mito import DataTypeInMito
 
 
 class MitoWidget(DOMWidget):
@@ -46,6 +48,7 @@ class MitoWidget(DOMWidget):
     sheet_json = t.Unicode('').tag(sync=True)
     code_json = t.Unicode('').tag(sync=True)
     df_names_json = t.Unicode('').tag(sync=True)
+    df_sources_json = t.Unicode('').tag(sync=True)
     df_shape_json = t.Unicode('').tag(sync=True)
     saved_analysis_names_json = t.Unicode('').tag(sync=True)
     column_spreadsheet_code_json = t.Unicode('').tag(sync=True)
@@ -53,13 +56,12 @@ class MitoWidget(DOMWidget):
     column_type_json = t.Unicode('').tag(sync=True)
     has_rendered = t.Bool(True).tag(sync=True)
     user_email = t.Unicode('').tag(sync=True)
-    step_data_list_json = t.Unicode('').tag(sync=True)
+    step_summaries_list_json = t.Unicode('').tag(sync=True)
     should_upgrade_mitosheet = t.Bool(False).tag(sync=True)
     data_type_in_mito = t.Unicode('').tag(sync=True)
     received_tours = t.Unicode('').tag(sync=True)
-    intended_behavior = t.Unicode('').tag(sync=True)
-    should_display_feedback = t.Bool(False).tag(sync=True)
-
+    num_feedbacks = t.Int(0).tag(sync=True)
+    num_usages = t.Int(0).tag(sync=True)
 
     def __init__(self, *args, **kwargs):
         """
@@ -76,7 +78,7 @@ class MitoWidget(DOMWidget):
         self.should_upgrade_mitosheet = should_upgrade_mitosheet()
             
         # Set up the state container to hold private widget state
-        self.widget_state_container = WidgetStateContainer(args)
+        self.steps_manager = StepsManager(args)
         
         # When the widget is first created, it has not been rendered on the frontend yet,
         # but after it is rendered once, this is set to False. This helps us detect 
@@ -90,12 +92,13 @@ class MitoWidget(DOMWidget):
         self.on_msg(self.receive_message)
 
         # And the api
-        self.api = API(self.widget_state_container, self.send)
+        self.api = API(self.steps_manager, self.send)
 
-        # We also set if the user should give feedback, which is something
-        # that does not change after the render, and so doesn't need to be
-        # updated after being set here
-        self.should_display_feedback = should_display_feedback()
+        # We also update the variables that mark how many times
+        # the user has given feedback, as well as how many times
+        # the user has used the tool
+        self.num_feedbacks = len(get_user_field(UJ_FEEDBACKS))
+        self.num_usages = len(get_user_field(UJ_MITOSHEET_LAST_FIFTY_USAGES))
 
 
     def update_shared_state_variables(self):
@@ -103,21 +106,21 @@ class MitoWidget(DOMWidget):
         Helper function for updating all the variables that are shared
         between the backend and the frontend through trailets.
         """
-        self.sheet_json = self.widget_state_container.sheet_json
-        self.curr_step_idx = self.widget_state_container.curr_step_idx
-        self.column_spreadsheet_code_json = self.widget_state_container.column_spreadsheet_code_json
-        self.code_json = self.widget_state_container.code_json
-        self.df_names_json = self.widget_state_container.df_names_json
-        self.df_shape_json = self.widget_state_container.df_shape_json
-        self.analysis_name = self.widget_state_container.analysis_name
+        self.sheet_json = self.steps_manager.sheet_json
+        self.curr_step_idx = self.steps_manager.curr_step_idx
+        self.column_spreadsheet_code_json = self.steps_manager.column_spreadsheet_code_json
+        self.code_json = self.steps_manager.code_json
+        self.df_names_json = self.steps_manager.df_names_json
+        self.df_sources_json = self.steps_manager.df_sources_json
+        self.df_shape_json = self.steps_manager.df_shape_json
+        self.analysis_name = self.steps_manager.analysis_name
         self.saved_analysis_names_json = saved_analysis_names_json()
-        self.column_filters_json = self.widget_state_container.column_filters_json
-        self.column_type_json = self.widget_state_container.column_type_json
-        self.user_email = self.widget_state_container.user_email
-        self.step_data_list_json = self.widget_state_container.step_data_list_json
-        self.data_type_in_mito = str(self.widget_state_container.data_type_in_mito)
-        self.received_tours = self.widget_state_container.received_tours
-        self.intended_behavior = self.widget_state_container.intended_behavior
+        self.column_filters_json = self.steps_manager.column_filters_json
+        self.column_type_json = self.steps_manager.column_type_json
+        self.user_email = self.steps_manager.user_email
+        self.step_summaries_list_json = self.steps_manager.step_summaries_list_json
+        self.data_type_in_mito = str(self.steps_manager.data_type_in_mito)
+        self.received_tours = self.steps_manager.received_tours
 
 
     def handle_edit_event(self, event):
@@ -131,13 +134,13 @@ class MitoWidget(DOMWidget):
         and the codeblock!
         """
         # First, we send this new edit to the evaluator
-        self.widget_state_container.handle_edit_event(event)
+        self.steps_manager.handle_edit_event(event)
 
         # We update the state variables 
         self.update_shared_state_variables()
 
         # Also, write the analysis to a file!
-        write_analysis(self.widget_state_container)
+        write_analysis(self.steps_manager)
 
         # Tell the front-end to render the new sheet and new code with an empty
         # response. NOTE: in the future, we can actually send back some data
@@ -164,13 +167,13 @@ class MitoWidget(DOMWidget):
             self.has_rendered = True
             return
 
-        self.widget_state_container.handle_update_event(event)
+        self.steps_manager.handle_update_event(event)
 
         # Update all state variables
         self.update_shared_state_variables()
 
         # Also, write the analysis to a file!
-        write_analysis(self.widget_state_container)
+        write_analysis(self.steps_manager)
 
         # Tell the front-end to render the new sheet and new code with an empty
         # response. NOTE: in the future, we can actually send back some data
@@ -208,13 +211,13 @@ class MitoWidget(DOMWidget):
             # NOTE: we don't need to case on log_event above because it always gets
             # passed to this function, and thus is logged. However, we do not log
             # api calls, as they are just noise.
-            log_event_processed(event, self.widget_state_container)
+            log_event_processed(event, self.steps_manager)
         except EditError as e:
             print(get_recent_traceback_as_list())
             print(e)
             
             # Log processing this event failed
-            log_event_processed(event, self.widget_state_container, failed=True, edit_error=e)
+            log_event_processed(event, self.steps_manager, failed=True, edit_error=e)
 
             # Report it to the user, and then return
             self.send({
@@ -227,7 +230,7 @@ class MitoWidget(DOMWidget):
         except:
             print(get_recent_traceback_as_list())
             # We log that processing failed, but have no edit error
-            log_event_processed(event, self.widget_state_container, failed=True)
+            log_event_processed(event, self.steps_manager, failed=True)
             # Report it to the user, and then return
             self.send({
                 'event': 'edit_error',
@@ -273,15 +276,11 @@ def sheet(
 
         # Log they have personal data in the tool if they passed a dataframe
         # that is not tutorial data or sample data from import docs
-        data_type_in_mito = get_data_type_in_mito(*args)
-        widget.widget_state_container.data_type_in_mito = data_type_in_mito
-        if data_type_in_mito == DataTypeInMito.PERSONAL:
+        if widget.steps_manager.data_type_in_mito == DataTypeInMito.PERSONAL:
             log('used_personal_data') 
 
     except:
-        # We log the error
         log_recent_error('mitosheet_sheet_call_failed')
-        # And then bubble it to the user
         raise
 
     # Then, we log that the call was successful, along with all of it's params
@@ -293,7 +292,7 @@ def sheet(
             },
             **{
                 # NOTE: analysis name is the UUID that mito saves the analysis under
-                'wsc_analysis_name': widget.widget_state_container.analysis_name,
+                'steps_manager_analysis_name': widget.steps_manager.analysis_name,
             },
             **{
                 'param_num_args': len(args),
