@@ -33,7 +33,7 @@ def execute_check_args_type(args):
 
 
 def transpile_check_args_type(
-        widget_state_container
+        steps_manager
     ):
     """
     This always returns nothing, because there it is just a sanity check
