@@ -1,18 +1,11 @@
-#!/usr/bin/env python
-# coding: utf-8
-
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
 """
 Stores utilities for changing the schemas for a saved analysis file,
 which requires a seperate upgrade process that upgrading specific
 steps within the file. 
 """
-from typing import Any, Dict, Optional
-from mitosheet._version import __version__
 
 
-def upgrade_saved_analysis_format_to_steps_data(saved_analysis: Optional[Dict[str, Any]]) -> Optional[Dict[str, Any]]:
+def upgrade_saved_analysis_format_to_steps_data(saved_analysis):
     """
     Upgrades a saved analysis to the current format without upgrading
     the specific individual steps! The current format of the saved analysis 
@@ -72,25 +65,4 @@ def upgrade_saved_analysis_format_to_steps_data(saved_analysis: Optional[Dict[st
             'steps_data': new_steps_data
         }
     else:
-        return saved_analysis
-
-
-
-def is_prev_version(version: str, curr_version: str=__version__) -> bool:
-    """
-    Returns True if the passed version is a previous version compared
-    to the current version; note that this assumes semantic versioning
-    with x.y.z!
-    """
-    old_version_parts = version.split('.')
-    curr_version_parts = curr_version.split('.')
-
-    for old_version_part, curr_version_part in zip(old_version_parts, curr_version_parts):
-        if int(old_version_part) > int(curr_version_part):
-            # E.g. if we have 0.2.11 and 0.1.11, we want to return early as it's clearly not older!
-            return False
-
-        if int(old_version_part) < int(curr_version_part):
-            return True
-
-    return False
\ No newline at end of file
+        return saved_analysis
\ No newline at end of file
