@@ -195,6 +195,51 @@ def update_filter_column_1_to_filter_column_2(step):
         "operator": step['operator']
     }
 
+def upgrade_merge_1_to_merge_2(step): 
+    """
+    Upgrades from a merge 1 step to a merge 2 step, simply
+    by adding the how param
+
+    We just set the how param to 'lookup' 
+
+    Old format of the step: {
+        'step_version': 1, 
+        'step_type': "merge", 
+        'params': {
+            'sheet_index_one': 0
+            'merge_key_one': 'A'
+            'selected_columns_one': ['A', 'B', 'C']
+            'sheet_index_two': 1
+            'merge_key_two': 'A'
+            'selected_columns_two': ['A', 'D']
+        }
+    }
+
+    New format of the step: {
+        'step_version': 1, 
+        'step_type': "merge",
+        'params': {
+            'how': 'lookup'
+            'sheet_index_one': 0
+            'merge_key_one': 'A'
+            'selected_columns_one': ['A', 'B', 'C']
+            'sheet_index_two': 1
+            'merge_key_two': 'A'
+            'selected_columns_two': ['A', 'D']
+        }
+    }
+    """
+
+    params = step['params']
+    # Add the how field to the params object and set it to 'lookup'
+    params['how'] = 'lookup'
+
+    return {
+        "step_version": 2, 
+        "step_type": "merge", 
+        "params": params
+    }
+
 
 
 """
@@ -212,7 +257,7 @@ this object should contain:
         }
     }
 """
-STEP_UPGRADES_FUNCTION_MAPPING = {
+STEP_UPGRADES_FUNCTION_MAPPING_OLD_FORMAT = {
     'group': {
         1: upgrade_group_1_to_pivot_2
     }, 
@@ -227,6 +272,13 @@ STEP_UPGRADES_FUNCTION_MAPPING = {
     }
 }
 
+STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT = {
+    'merge': {
+        1: upgrade_merge_1_to_merge_2
+    }
+}
+
+
 
 def is_prev_version(version: str, curr_version: str=__version__):
     """
@@ -247,34 +299,22 @@ def is_prev_version(version: str, curr_version: str=__version__):
 
     return False
 
-def needs_upgrade(steps):
-    """
-    Returns True if _any_ of the steps in this step dictionary
-    needs to be upgraded!
-    """
-    for step_idx, step in steps.items():
-        step_version = step['step_version']
-        step_type = step['step_type']
 
-        if step_type in STEP_UPGRADES_FUNCTION_MAPPING:
-            step_upgrades = STEP_UPGRADES_FUNCTION_MAPPING[step_type]
-            if step_version in step_upgrades:
-                return True
-
-    return False
-
-def upgrade_step_to_current(step):
+def upgrade_step_to_current(step, step_upgrade_function_mapping):
     """
     A recursive helper function that, given a step, keeps upgrading it
     until it cannot be upgraded anymore
+
+    Takes a step_upgrade_function_mapping as input, which can either be 
+    STEP_UPGRADES_FUNCTION_MAPPING_OLD_FORMAT or STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT
     """
     step_version = step['step_version']
     step_type = step['step_type']
 
-    if step_type in STEP_UPGRADES_FUNCTION_MAPPING:
-        step_upgrades = STEP_UPGRADES_FUNCTION_MAPPING[step_type]
+    if step_type in step_upgrade_function_mapping:
+        step_upgrades = step_upgrade_function_mapping[step_type]
         if step_version in step_upgrades:
-            return upgrade_step_to_current(step_upgrades[step_version](step))
+            return upgrade_step_to_current(step_upgrades[step_version](step), step_upgrade_function_mapping)
     
     return step
 
@@ -307,7 +347,7 @@ def upgrade_steps_for_old_format(saved_analysis):
 
     new_steps = []
     for step_idx, step in steps.items():
-        new_steps.append(upgrade_step_to_current(step))
+        new_steps.append(upgrade_step_to_current(step, STEP_UPGRADES_FUNCTION_MAPPING_OLD_FORMAT))
 
     # Convert the new steps in the correct format
     new_steps_json = {
@@ -319,6 +359,38 @@ def upgrade_steps_for_old_format(saved_analysis):
         'steps': new_steps_json
     }
 
+def upgrade_steps_for_new_format(saved_analysis):
+    """
+    A helper function that operates on the new analysis format of:
+
+    "version": "0.1.197",
+    "steps_data": [
+        {
+            "step_version": 1,
+            "step_type": "filter",
+            "params": {
+                ....
+            }
+        }
+    ]
+
+    And makes sure all their steps are up to date.
+    """
+    if saved_analysis is None:
+        return None
+        
+    version = saved_analysis["version"]
+    steps_data = saved_analysis["steps_data"]
+
+    new_steps_data = []
+    for step in steps_data:
+        new_steps_data.append(upgrade_step_to_current(step, STEP_UPGRADES_FUNCTION_MAPPING_NEW_FORMAT))
+
+    return {
+        'version': __version__,
+        'steps_data': new_steps_data
+    }
+
 def upgrade_saved_analysis_to_current_version(saved_analysis):
     """
     Upgrades a saved analysis to the current version.
@@ -333,8 +405,7 @@ def upgrade_saved_analysis_to_current_version(saved_analysis):
     """
     saved_analysis = upgrade_steps_for_old_format(saved_analysis)
     new_format_saved_analysis = upgrade_saved_analysis_format_to_steps_data(saved_analysis)
+    saved_analysis = upgrade_steps_for_new_format(new_format_saved_analysis)
 
-    # NOTE: in the future, when upgrading steps, put the upgrading here!
-
-    return new_format_saved_analysis
+    return saved_analysis
     
\ No newline at end of file
