@@ -448,6 +448,34 @@ def VALUE(series) -> pd.Series:
     return series
 
 
+@handle_sheet_function_errors
+@filter_nans
+@convert_arg_to_series_type(
+    0,
+    NUMBER_SERIES,
+    'error',
+    ('default', np.NaN)
+)
+def EXP(series) -> pd.Series:
+    """
+    {
+        "function": "EXP",
+        "description": "Returns e, the base of the natural logarithm, raised to the power of passed series.",
+        "examples": [
+            "=EXP(data)",
+            "=EXP(A)"
+        ],
+        "syntax": "EXP(series)",
+        "syntax_elements": [{
+                "element": "series",
+                "description": "The series to raise e to."
+            }
+        ]
+    }
+    """
+    return np.exp(series)
+
+
 @handle_sheet_function_errors
 @convert_arg_to_series_type(
     0,
@@ -483,6 +511,7 @@ NUMBER_FUNCTIONS = {
     'ABS': ABS,
     'AVG': AVG,
     'CORR': CORR,
+    'EXP': EXP,
     'KURT': KURT,
     'MAX': MAX,
     'MIN': MIN,
