@@ -52,6 +52,17 @@ def is_datetime_dtype(dtype):
 def is_timedelta_dtype(dtype):
     return 'timedelta' in dtype
 
+def get_float_columns(df: pd.DataFrame):
+    """
+    Returns all the float column_headers in the
+    passed dataframe
+    """
+    float_columns = []
+    for column_header in df.columns:
+        if is_float_dtype(str(df[column_header].dtype)):
+            float_columns.append(column_header)
+    return float_columns
+
 def get_datetime_columns(df: pd.DataFrame):
     """
     Returns all the datetime column_headers in the
@@ -163,3 +174,23 @@ def put_nan_indexes_back(series, nan_indexes):
 
     final_series = pd.Series(final_series)
     return final_series
+
+def get_datetime_format(string_series):
+    """
+    Given a series of datetime strings, detects if the format is MM-DD-YYYY,
+    which is the most common format that pandas does not default to.
+
+    In the future, we can extend this to detect other formats. Returns None
+    if infer_datetime_format is good enough!
+    """
+    try:
+        # If we can convert all non null inputs, then we assume that pandas
+        # is guessing the input correctly
+        non_null_inputs = string_series[~string_series.isna()]
+        converted = pd.to_datetime(non_null_inputs, errors='coerce', infer_datetime_format=True)
+        if converted.isna().sum() > 0:
+            raise Exception("Non full conversion")
+        return None
+    except:
+        # Otherwise, we return true, as this is most likely the format
+        return '%m-%d-%Y'
\ No newline at end of file
