@@ -1,18 +1,12 @@
-#!/usr/bin/env python
-# coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
-
-from typing import Any, Dict, List, Optional, Set, Type
-from mitosheet.evaluation_graph_utils import create_column_evaluation_graph
 
 from mitosheet.step_performers.step_performer import StepPerformer
 from mitosheet.step_performers.column_steps.set_column_formula import SetColumnFormulaStepPerformer
 from mitosheet.step_performers.filter import FilterStepPerformer
+from typing import Any, Dict, List, Optional
+
 from mitosheet.state import State
 from mitosheet.step_performers import STEP_TYPE_TO_STEP_PERFORMER
-from mitosheet.types import ColumnHeader, ColumnID
 
 
 class Step:
@@ -77,8 +71,12 @@ class Step:
         return self.post_state.df_sources
 
     @property
-    def column_ids(self):
-        return self.post_state.column_ids
+    def column_metatype(self):
+        return self.post_state.column_metatype
+
+    @property
+    def column_type(self):
+        return self.post_state.column_type
     
     @property
     def column_spreadsheet_code(self):
@@ -86,29 +84,18 @@ class Step:
 
     @property
     def column_evaluation_graph(self):
-        return [
-            create_column_evaluation_graph(self.post_state, sheet_index)
-            for sheet_index in range(len(self.dfs))
-        ]
+        return self.post_state.column_evaluation_graph
+
+    @property
+    def column_python_code(self):
+        return self.post_state.column_python_code
     
     @property
     def column_filters(self):
         return self.post_state.column_filters
 
     @property
-    def column_format_types(self):
-        return self.post_state.column_format_types
-
-    @property
-    def graph_data_dict(self) -> Dict[str, Dict[str, Any]]:
-        """
-        graph_data_dict contains all of the parameters used to construct the graph,
-        the actual graph html & javascript, and the generated code for all of the existing graphs in Mito.
-        """
-        return self.final_defined_state.graph_data_dict
-
-    @property
-    def step_performer(self) -> Type[StepPerformer]:
+    def step_performer(self) -> StepPerformer:
         """
         A helper function to return the step performer class
         that is associated with this step, based on step type.
@@ -119,16 +106,8 @@ class Step:
         step_performer = STEP_TYPE_TO_STEP_PERFORMER[self.step_type]
         return step_performer
 
-    @property
-    def final_defined_state(self) -> State:
-        """
-        Returns the final defined state in this step, as the prev and post
-        state are optional, but we also need a step to have a defined state
-        """
-        return self.post_state if self.post_state is not None else \
-            (self.prev_state if self.prev_state is not None else State([]))
 
-    def set_prev_state_and_execute(self, new_prev_state: State) -> None:
+    def set_prev_state_and_execute(self, new_prev_state):
         """
         Changes the prev_state of this step, which in turns triggers
         a reexecution with the same parameters. 
@@ -146,8 +125,7 @@ class Step:
         post_state_and_execution_data = self.step_performer.execute(new_prev_state, **params)
 
         if post_state_and_execution_data is not None:
-            # If we don't get anything new back, then we just make this
-            # step a no-op, and don't do anything
+            # 
             (new_post_state, execution_data) = post_state_and_execution_data
         else:
             # Sometimes step execution returns None, which functionally means that 
@@ -162,7 +140,7 @@ class Step:
         self.params = params
     
 
-    def step_indexes_to_skip(self, all_steps_before_this_step: List['Step']) -> Set[int]:
+    def step_indexes_to_skip(self, all_steps_before_this_step):
         """
         Given the steps that come before it, any step has the ability
         to skip these steps. 
@@ -176,10 +154,11 @@ class Step:
         step_indexes_to_skip = set()
 
         for step_index, step in enumerate(all_steps_before_this_step):
+            step: Step = step
             # Check (1)
             if step.step_type == FilterStepPerformer.step_type() and self.step_type == FilterStepPerformer.step_type():
                 if step.params['sheet_index'] == self.params['sheet_index'] \
-                    and step.params['column_id'] == self.params['column_id']:
+                    and step.params['column_header'] == self.params['column_header']:
                    step_indexes_to_skip.add(step_index) 
             
             # Check (2)
@@ -189,34 +168,14 @@ class Step:
         if len(all_steps_before_this_step) > 0:
             previous_step: Step = all_steps_before_this_step[-1]
             
+            
             # Check (3)
             if self.step_type == SetColumnFormulaStepPerformer.step_type():
                 if self.step_type == previous_step.step_type \
                     and self.params['sheet_index'] == previous_step.params['sheet_index'] \
-                    and self.params['column_id'] == previous_step.params['column_id']:
+                    and self.params['column_header'] == previous_step.params['column_header']:
                     step_indexes_to_skip.add(len(all_steps_before_this_step) - 1)
 
         return step_indexes_to_skip
 
-    def get_column_headers_by_ids(self, sheet_index: int, column_ids: List[ColumnID]) -> List[Any]:
-        """
-        Utility for getting the column headers from column ids in a step.
-        First attempts to get them from the prev state, but if not 
-        """
-        return self.final_defined_state.column_ids.get_column_headers_by_ids(sheet_index, column_ids)
-            
-    def get_column_header_by_id(self, sheet_index: int, column_id: ColumnID) -> Any:
-        """
-        Utility for getting the column header from a column id in a step.
-        First attempts to get them from the prev state, but if not 
-        """
-        return self.final_defined_state.column_ids.get_column_header_by_id(sheet_index, column_id)
-
-    def get_column_id_by_header(self, sheet_index: int, column_header: ColumnHeader) -> str:
-        """
-        Utility for getting the column id from a column header in a step.
-        First attempts to get them from the prev state, but if not 
-        """
-        return self.final_defined_state.column_ids.get_column_id_by_header(sheet_index, column_header)
-
 
