@@ -22,7 +22,7 @@ class MergeStepPerformer(StepPerformer):
 
     @classmethod
     def step_version(cls) -> int:
-        return 1
+        return 2
 
     @classmethod
     def step_type(cls) -> str:
@@ -44,6 +44,7 @@ class MergeStepPerformer(StepPerformer):
     def execute(
         cls,
         prev_state: State,
+        how: str,
         sheet_index_one: int,
         merge_key_one: str,
         selected_columns_one: List[str],
@@ -74,6 +75,7 @@ class MergeStepPerformer(StepPerformer):
         new_df = _execute_merge(
             prev_state.dfs,
             prev_state.df_names,
+            how,
             sheet_index_one,
             merge_key_one,
             selected_columns_one,
@@ -93,6 +95,7 @@ class MergeStepPerformer(StepPerformer):
         prev_state: State,
         post_state: State,
         execution_data: Optional[Dict[str, Any]],
+        how: str,
         sheet_index_one: int,
         merge_key_one: str,
         selected_columns_one: List[str],
@@ -100,15 +103,23 @@ class MergeStepPerformer(StepPerformer):
         merge_key_two: str,
         selected_columns_two: List[str]
     ) -> List[str]:
+
         # update df indexes to start at 1
         df_one_name = post_state.df_names[sheet_index_one]
         df_two_name = post_state.df_names[sheet_index_two]
         df_new_name = post_state.df_names[len(post_state.dfs) - 1]
 
-        # Now, we build the merge code (starting with the code for dropping duplicates)
-        merge_code = [
-            f'temp_df = {df_two_name}.drop_duplicates(subset=\'{merge_key_two}\')',
-        ]
+        # Now, we build the merge code 
+        merge_code = []
+        if how == 'lookup':
+            # If the mege is a lookup, then we add the drop duplicates code
+            temp_df_name = 'temp_df'
+            merge_code.append(f'{temp_df_name} = {df_two_name}.drop_duplicates(subset=\'{merge_key_two}\') # Remove duplicates so lookup merge only returns first match')
+            how_to_use = 'left'
+        else:
+            temp_df_name = df_two_name
+            how_to_use = how
+
 
         # If we are only taking some columns, write the code to drop the ones we don't need!
         deleted_columns_one = set(post_state.dfs[sheet_index_one].keys()).difference(set(selected_columns_one))
@@ -119,12 +130,12 @@ class MergeStepPerformer(StepPerformer):
             )
         if len(deleted_columns_two) > 0:
             merge_code.append(
-                f'{df_two_name}_tmp = temp_df.drop({list(deleted_columns_two)}, axis=1)'
+                f'{df_two_name}_tmp = {temp_df_name}.drop({list(deleted_columns_two)}, axis=1)'
             )
 
         # If we drop columns, we merge the new dataframes
         df_one_to_merge = df_one_name if len(deleted_columns_one) == 0 else f'{df_one_name}_tmp'
-        df_two_to_merge = 'temp_df' if len(deleted_columns_two) == 0 else f'{df_two_name}_tmp'
+        df_two_to_merge = temp_df_name if len(deleted_columns_two) == 0 else f'{df_two_name}_tmp'
 
         # We insist column names are unique in dataframes, so while we default the suffixes to be the dataframe
         # names
@@ -133,7 +144,7 @@ class MergeStepPerformer(StepPerformer):
 
         # Finially append the merge
         merge_code.append(
-            f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[\'{merge_key_one}\'], right_on=[\'{merge_key_two}\'], how=\'left\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
+            f'{df_new_name} = {df_one_to_merge}.merge({df_two_to_merge}, left_on=[\'{merge_key_one}\'], right_on=[\'{merge_key_two}\'], how=\'{how_to_use}\', suffixes=[\'_{suffix_one}\', \'_{suffix_two}\'])'
         )
 
         # And then return it
@@ -142,6 +153,7 @@ class MergeStepPerformer(StepPerformer):
     @classmethod
     def describe(
         cls,
+        how: str,
         sheet_index_one: int,
         merge_key_one: str,
         selected_columns_one: List[str],
@@ -160,6 +172,7 @@ class MergeStepPerformer(StepPerformer):
 def _execute_merge(
         dfs, 
         df_names,
+        how,
         sheet_index_one,
         merge_key_one, 
         selected_columns_one,
@@ -170,11 +183,15 @@ def _execute_merge(
     """
     Executes a merge on the sheets with the given indexes, merging on the 
     given keys, and only keeping the selection columns from each df.
-    
-    TODO: figure out how to simulate VLOOKUP style work better here...
     """
-    # We drop duplicates to avoid pairwise duplication on the merge.
-    temp_df = dfs[sheet_index_two].drop_duplicates(subset=merge_key_two)
+    if how == 'lookup':
+        # We drop duplicates to avoid pairwise duplication on the merge.
+        temp_df = dfs[sheet_index_two].drop_duplicates(subset=merge_key_two)
+        # We overwrite the how variable to 'left' so it can be used in the merge
+        how_to_use = 'left'
+    else:
+        temp_df = dfs[sheet_index_two]
+        how_to_use = how
 
     # Then we delete all the columns from each we don't wanna keep
     deleted_columns_one = set(dfs[sheet_index_one].keys()).difference(set(selected_columns_one))
@@ -191,4 +208,4 @@ def _execute_merge(
     suffix_one = df_one_name
     suffix_two = df_two_name if df_two_name != df_one_name else f'{df_two_name}_2'
 
-    return df_one_cleaned.merge(df_two_cleaned, left_on=[merge_key_one], right_on=[merge_key_two], how='left', suffixes=[f'_{suffix_one}', f'_{suffix_two}'])
\ No newline at end of file
+    return df_one_cleaned.merge(df_two_cleaned, left_on=[merge_key_one], right_on=[merge_key_two], how=how_to_use, suffixes=[f'_{suffix_one}', f'_{suffix_two}'])
\ No newline at end of file
