@@ -1,16 +1,16 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# Copyright (c) Saga Inc.
-# Distributed under the terms of the GPL License.
+# Copyright (c) Mito.
+# Distributed under the terms of the Modified BSD License.
+
 import pandas as pd
 import pytest
 
 from mitosheet.utils import get_new_id
-from mitosheet.errors import MitoError
+from mitosheet.errors import EditError
 from mitosheet.steps_manager import StepsManager
 from mitosheet.tests.test_utils import create_mito_wrapper
-from mitosheet.column_headers import get_column_header_id
 
 
 def test_create_steps_manager():
@@ -20,7 +20,11 @@ def test_create_steps_manager():
     steps_manager = StepsManager([df1, df2])
     assert steps_manager.curr_step_idx == 0
     assert steps_manager.curr_step.step_type == 'initialize'
+    assert steps_manager.curr_step.column_metatype == [{'A': 'value'}, {'A': 'value'}]
     assert steps_manager.curr_step.column_spreadsheet_code == [{'A': ''}, {'A': ''}]
+    assert steps_manager.curr_step.column_python_code == [{'A': ''}, {'A': ''}]
+    assert steps_manager.curr_step.column_evaluation_graph == [{'A': set()}, {'A': set()}]
+    assert steps_manager.curr_step.column_python_code == [{'A': ''}, {'A': ''}]
     assert steps_manager.curr_step.dfs[0].equals(df1)
     assert steps_manager.curr_step.dfs[1].equals(df2)
 
@@ -33,15 +37,16 @@ CELL_EDIT_ERRORS = [
     ('=C + D', 'no_column_error'),
     ('=ABCDEFG', 'no_column_error'),
     ('=UPPER(C)', 'no_column_error'),
-    ('=UPPER(A, 100)', 'function_error'),
-    ('=UPPER(LOWER(A, 100))', 'function_error')
+    ('=B', 'circular_reference_error'),
+    ('=UPPER(A, 100)', 'execution_error'),
+    ('=UPPER(LOWER(A, 100))', 'execution_error')
 ]
 
 @pytest.mark.parametrize("formula,error_type", CELL_EDIT_ERRORS)
 def test_steps_manager_cell_edit_errors(formula,error_type):
     mito = create_mito_wrapper([123])
     mito.add_column(0, 'B')
-    with pytest.raises(MitoError) as e_info:
+    with pytest.raises(EditError) as e_info:
         mito.mito_widget.steps_manager.handle_edit_event({
             'event': 'edit_event',
             'id': get_new_id(),
@@ -49,13 +54,31 @@ def test_steps_manager_cell_edit_errors(formula,error_type):
             'step_id': get_new_id(),
             'params': {
                 'sheet_index': 0,
-                'column_id': get_column_header_id('B'),
+                'column_header': 'B',
                 'old_formula': '=0',
                 'new_formula': formula
             }
         })
     assert e_info.value.type_ == error_type
 
+def test_wrong_column_metatype():
+    mito = create_mito_wrapper([123])
+    mito.add_column(0, 'B')
+    with pytest.raises(EditError) as e_info:
+        mito.mito_widget.steps_manager.handle_edit_event({
+            'event': 'edit_event',
+            'id': get_new_id(),
+            'type': 'set_column_formula_edit',
+            'step_id': get_new_id(),
+            'params': {
+                'sheet_index': 0,
+                'column_header': 'A',
+                'old_formula': '=0',
+                'new_formula': '=1'
+            }
+        })
+    assert e_info.value.type_ == 'wrong_column_metatype_error'
+
 
 def test_overwrites_step_valid():
     mito = create_mito_wrapper([1, 2, 3])
@@ -73,8 +96,9 @@ def test_overwrites_step_valid():
         }
     })
 
-    assert len(mito.steps_including_skipped) == 3
-    assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'C': [0, 0, 0]}))
+    steps_manager = mito.mito_widget.steps_manager
+    assert len(steps_manager.steps) == 3
+    assert steps_manager.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'C': [0, 0, 0]}))
 
 
 def test_failed_overwrite_rolls_back_to_previous_state():
@@ -93,7 +117,8 @@ def test_failed_overwrite_rolls_back_to_previous_state():
         }
     })
 
-    assert len(mito.steps_including_skipped) == 2
-    assert mito.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'B': [0, 0, 0]}))
+    steps_manager = mito.mito_widget.steps_manager
+    assert len(steps_manager.steps) == 2
+    assert steps_manager.dfs[0].equals(pd.DataFrame(data={'A': [1, 2, 3], 'B': [0, 0, 0]}))
 
 
