@@ -8,7 +8,7 @@
 Rename an existing saved analysis.
 """
 
-from mitosheet.save_utils import rename_saved_analysis
+from mitosheet.saved_analyses import rename_saved_analysis
 
 RENAME_SAVED_ANALYSIS_UPDATE_EVENT = 'rename_analysis_update'
 RENAME_SAVED_ANALYSIS_UPDATE_PARAMS = [
@@ -17,7 +17,7 @@ RENAME_SAVED_ANALYSIS_UPDATE_PARAMS = [
 ]
 
 def execute_rename_saved_analysis_update(
-        wsc,
+        steps_manager,
         old_analysis_name,
         new_analysis_name
     ):
